# Interactive Example Notebooks

(For now) this folder follows the structure of `rail/pipeline_examples`. Notebooks are added as
they are ported to work with the interactive module of rail.

## Intentionally Absent Notebooks

These notebooks do not make sense in the interactive context, and so are omitted

- core_examples/
  - 00_Useful_Utilities.ipynb
  - 01_FileIO_DataStore.ipynb
  - 04_Iterate_Tabular_Data.ipynb
  - 05_Build_Save_Load_Run_Pipeline.ipynb
  - 06_Rail_Interfaces.ipynb
- creation_examples/
  - 04_Plotting_interface_skysim_cosmoDC2_COSMOS2020.ipynb
- estimation_examples/
  - 03_BPZ_lite_Custom_SEDs.ipynb - very complicated with lots of external data
  - 08_NZDir_pipeline.ipynb
  - 10_YAW.ipynb - due to ongoing issues with YAW missing from interactive
  - 12_SomocluSOM_Quality_Control.ipynb - same as 03
